@@ -108,7 +108,7 @@ class CorpusDict:
         with open(file_path, 'wb') as f:
             pickle.dump(self.backup(), f, 2)
 
-    def restore(self, o):
+    def restore(self, o, log_file=LOG_FILE):
         """Restore current state from backup object"""
         (self._cnt_thresh      ,
          self._ambiguity_thresh,
@@ -143,12 +143,12 @@ class CorpusDict:
             [k for k, _ in sorted(vals.items(), key=itemgetter(1))]
                 for vals in self._feat_vals_id
         )
-        self.fit()
+        self.fit(log_file=log_file)
 
-    def restore_from(self, file_path):
+    def restore_from(self, file_path, log_file=LOG_FILE):
         """Restore current state from file"""
         with open(file_path, 'rb') as f:
-            self.restore(pickle.load(f))
+            self.restore(pickle.load(f), log_file=log_file)
 
     def isempty(self):
         """Check if current state does not contain any information"""
@@ -566,6 +566,14 @@ class CorpusDict:
             res = self._wform_tag_cnts[res].get(self._tags_id[tag])
         return res is not None
 
+    def lemma_isknown(self, lemma, tag=None):
+        res = self._lemmata_id.get(lemma)
+        if res is None:
+            res = self._lemmata_id.get(lemma.lower())
+        if res is not None and tag:
+            res = self._lemma_tag_cnts[res].get(self._tags_id[tag])
+        return res is not None
+
     def most_common_tag(self):
         """Return most common tag for the whole corpus"""
         return self._most_common_tag
